.. _notebooks:

Example Jupyter Notebooks
===========================

A collection of demonstration notebooks showcasing the use of community developed
lightcurve and activity classes.


Lightcurve Example Notebooks
-------------------------------

.. NOTE: Please add new notebooks alphabetically

Sinusoidal Lightcurve Class 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 1
    
    Sinusoidal Lightcurve <notebooks/lightcurve/sinusoidal/sinusoidal_example>
    Sorcha Calculations Using the Sinusoidal Lightcurve Class <notebooks/lightcurve/sinusoidal/demo_Sinusoidal_Lightcurve_within_Sorcha>

Activity Example Notebooks
------------------------------
.. NOTE: Please add new notebooks alphabetically

LSST Comet Class
~~~~~~~~~~~~~~~~~~~~
.. toctree::
    :maxdepth: 1

    LSST Comet <notebooks/activity/lsst_comet/simple_cometary_magnitude>
    Sorcha Calculations Using the LSST Comet Class <notebooks/activity/lsst_comet/demo_LSSTComet_within_Sorcha>

